pub struct GetClientVersionV1Request { /* private fields */ }Expand description
Request handler for engine_getClientVersionV1.
This method allows consensus and execution layer clients to exchange version information. The execution client returns its own version information in response.