clean_outdated_filters

Function clean_outdated_filters 

pub fn clean_outdated_filters(filters: ActiveFilters, filter_duration: Duration)
Used by the tokio runtime to clean outdated filters Takes 2 arguments:

  • filters: the filters to clean up.
  • filter_duration: represents how many seconds filter can last, if any filter is older than this, it will be removed.