pub async fn map_http_requests(
req: &RpcRequest,
context: RpcApiContext,
) -> Result<Value, RpcErr>Expand description
Handle requests that can come from either clients or other users
pub async fn map_http_requests(
req: &RpcRequest,
context: RpcApiContext,
) -> Result<Value, RpcErr>Handle requests that can come from either clients or other users