Structs
- Client
Version - Client version information used for identification in the Engine API and P2P.
- Node
Data - Node identity and configuration information.
- RpcApi
Context - This struct contains all the dependencies that RPC handlers need to process requests, including storage access, blockchain state, P2P networking, and configuration.
- WebSocket
Config - Configuration for the WebSocket RPC server.
Enums
- RpcRequest
Wrapper - Wrapper for JSON-RPC requests that can be either single or batched.
Constants
- FILTER_
DURATION - Duration after which inactive filters are cleaned up.
Traits
- RpcHandler
- Trait for implementing JSON-RPC method handlers.
Functions
- handle_
authrpc_ request - handle_
eth_ subscribe - Handle
eth_subscribe. - handle_
eth_ unsubscribe - Handle
eth_unsubscribe. - handle_
get_ heap - handle_
get_ heap_ flamegraph - handle_
websocket - Handle a WebSocket connection.
- map_
admin_ requests - map_
authrpc_ requests - Handle requests from consensus client
- map_
debug_ requests - Routes
debug_*namespace requests to their handlers. - map_
engine_ requests - Routes
engine_*namespace requests to their handlers. - map_
eth_ requests - Routes
eth_*namespace requests to their handlers. - map_
http_ requests - Handle requests that can come from either clients or other users
- map_
mempool_ requests - map_
net_ requests - map_
web3_ requests - rpc_
response - Formats a handler result into a JSON-RPC 2.0 response.
- shutdown_
signal - Returns a future that completes when SIGINT (Ctrl+C) is received.
- start_
api - Starts the JSON-RPC API servers.
- start_
block_ executor - Spawns a dedicated thread for sequential block execution.